@@ -11,10 +11,11 @@ from .check_version import CheckVersionMessage
 class WaitWindow(QWidget):
     sigUpdateClicked = pyqtSignal()
     sigRestartClicked = pyqtSignal()
+    sigCheckClicked = pyqtSignal()
 
     log = logging.getLogger(__name__)
 
-    def __init__(self, label: str = 'Check for updates ... ', parent=None):
+    def __init__(self, label: str = 'You use the latest version!', parent=None):
         super().__init__(parent)
         self.setWindowFlag(Qt.Window)
         self.setWindowFlag(Qt.FramelessWindowHint)
@@ -22,21 +23,29 @@ class WaitWindow(QWidget):
         # self.setWindowModality(Qt.ApplicationModal)
 
         self.spinner = Spinner(self)
+        self.spinner.pause()
+        self.spinner.hide()
+
+        self.check_button = QPushButton('Check for updates')
+        self.check_button.clicked.connect(self.sigCheckClicked)
+
         self.update_button = QPushButton('Update')
-        self.update_button.clicked.connect(self._update_clicked)
+        self.update_button.clicked.connect(self.sigUpdateClicked)
         self.update_button.hide()
         self.update_button.setDisabled(True)
 
         self.restart_button = QPushButton('Restart')
-        self.restart_button.clicked.connect(self.sigRestartClicked.emit)
+        self.restart_button.clicked.connect(self.sigRestartClicked)
         self.restart_button.hide()
         self.restart_button.setDisabled(True)
 
         self.label = QLabel(label)
-        self.setMinimumWidth(500)
-        self.setFixedHeight(70)
+        self.setMinimumWidth(700)
+        self.setFixedHeight(150)
+
         layout = QGridLayout(self)
         layout.addWidget(self.spinner, 0, 0)
+        layout.addWidget(self.check_button, 1, 0, 1, 3)
         layout.addWidget(self.label, 0, 1)
         layout.addWidget(self.update_button, 0, 2)
         layout.addWidget(self.restart_button, 0, 3)
@@ -47,11 +56,19 @@ class WaitWindow(QWidget):
     def set_text(self, text: str):
         self.label.setText(text)
 
-    def _update_clicked(self):
+    def on_checking(self):
+        self.spinner.show()
+        self.spinner.resume()
+        self.check_button.setDisabled(True)
+
+    def on_update(self):
         self.spinner.show()
         self.spinner.resume()
         self.label.setText('Updating version ...')
         self.update_button.hide()
+        self.check_button.hide()
+
+    def _update_clicked(self):
         self.sigUpdateClicked.emit()
 
     def show_info(self, text: str, hide_spinner: bool = True):
@@ -59,6 +76,7 @@ class WaitWindow(QWidget):
             self.spinner.pause()
             self.spinner.hide()
         self.label.setText(text)
+        self.check_button.show()
 
     def show_restart(self):
         self.spinner.pause()
@@ -79,5 +97,9 @@ class WaitWindow(QWidget):
             self.set_text(f'New version available: {res.version}. Please, update your program.')
             self.update_button.setDisabled(False)
             self.update_button.show()
+
         self.spinner.pause()
         self.spinner.hide()
+
+        self.check_button.show()
+        self.check_button.setDisabled(False)
